==> illuminaMousev1.db_1.10.0.tar.gz: illuminaMousev1.db/man/illuminaMousev1NewMappings.Rd <==
\name{illuminaMousev1listNewMappings}
\alias{illuminaMousev1ARRAYADDRESS}
\alias{illuminaMousev1NUID}
\alias{illuminaMousev1PROBESEQUENCE}
\alias{illuminaMousev1PROBEQUALITY}
\alias{illuminaMousev1CODINGZONE}
\alias{illuminaMousev1GENOMICLOCATION}
\alias{illuminaMousev1GENOMICMATCHSIMILARITY}
\alias{illuminaMousev1SECONDMATCHES}
\alias{illuminaMousev1SECONDMATCHSIMILARITY}
\alias{illuminaMousev1TRANSCRIPTOMICMATCHSIMILARITY}
\alias{illuminaMousev1OTHERGENOMICMATCHES}
\alias{illuminaMousev1REPEATMASK}
\alias{illuminaMousev1CONTAINSSNP}
\alias{illuminaMousev1ENTREZREANNOTATED}
\alias{illuminaMousev1ENSEMBLREANNOTATED}
\alias{illuminaMousev1listNewMappings}
\alias{illuminaMousev1fullReannotation}


\title{Custom mappings added to the package}
\description{
We have used an extensive re-annotation of the illuminaMousev1 probe sequences to provide additional information that is not captured in the standard Bioconductor packages. Whereas Bioconductor annotations are based on the RefSeq ID that each probe maps to, our additional mappings provide data specific to each probe on the platform. See below for details. We recommend using the probe quality as a form of filtering, and retaining only perfect or good probes for an analysis. 

}

\section{Details of custom mappings}{

\describe{

\item{illuminaMousev1listNewMappings}{List all the custom re-annotation mappings provided by the package}

\item{illuminaMousev1fullReannotation}{Return all the re-annotation information as a matrix}

\item{illuminaMousev1ARRAYADDRESS}{Array Address code used to identify the probe at the bead-level}

\item{illuminaMousev1NUID}{Lumi's nuID (universal naming scheme for oligonucleotides) Reference: Du et al. (2007), Biol Direct 2:16}

\item{illuminaMousev1PROBESEQUENCE}{The 50 base sequence for the probe}

\item{illuminaMousev1PROBEQUALITY}{Quality grade assigned to the probe: \dQuote{Perfect} if it perfectly and uniquely matches the target transcript; \dQuote{Good} if the probe, although imperfectly matching the target transcript, is still likely to provide considerably sensitive signal (up to two mismatches are allowed, based on empirical evidence that the signal intensity for 50-mer probes with less than 95\% identity to the respective targets is less than 50\% of the signal associated with perfect matches *); \dQuote{Bad} if the probe matches repeat sequences, intergenic or intronic regions, or is unlikely to provide specific signal for any transcript; \dQuote{No match} if it does not match any genomic region or transcript.}

\item{illuminaMousev1CODINGZONE}{Coding status of target sequence: intergenic / intronic / 5'UTR / CDS / 3'UTR (\dQuote{Transcriptomic} when the target transcript is non-coding or there is no information on the coding sequence)}


\item{illuminaMousev1GENOMICLOCATION}{Probe's genomic coordinates (hg19 for human, mm9 for mouse or rn4 for rat)}

\item{illuminaMousev1GENOMICMATCHSIMILARITY}{Percentage of similarity between the probe and its best genomic match in the alignable region, taking the probe as reference}

\item{illuminaMousev1SECONDMATCHES}{Genomic coordinates of second best matches between the probe and the genome}

\item{illuminaMousev1SECONDMATCHSIMILARITY}{Percentage of similarity between the probe and its second best genomic match in the alignable region, taking the probe as reference}

\item{illuminaMousev1TRANSCRIPTOMICMATCHSIMILARITY}{Percentage of similarity between the probe and its target transcript in the alignable region, taking the probe as reference}

\item{illuminaMousev1OTHERGENOMICMATCHES}{Genomic coordinates of sequences as alignable with the probe (in terms of number of matching nucleotides) as its main target}

\item{illuminaMousev1REPEATMASK}{Overlapping RepeatMasked sequences, with number of bases overlapped by the repeat}

\item{illuminaMousev1CONTAINSSNP}{Overlapping annotated SNPs}

\item{illuminaMousev1ENTREZREANNOTATED}{Entrez IDs}

\item{illuminaMousev1ENSEMBLREANNOTATED}{Ensembl IDs}



}

}

\references{
  \url{http://remoat.sysbiol.cam.ac.uk}


 Barbosa-Morais et al. (2010) A re-annotation pipeline for Illumina BeadArrays: improving the interpretation of gene expression data. Nucleic Acids Research

}
\examples{

	##See what new mappings are available

	illuminaMousev1listNewMappings()
	

        x <- illuminaMousev1PROBEQUALITY

        mapped_probes <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_probes])
        if(length(xx) > 0) {
          # Get the PROBEQUALITY for the first five probes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }


	##Overall table of qualities
	table(unlist(xx))

	

        x <- illuminaMousev1ARRAYADDRESS

        mapped_probes <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_probes])
        if(length(xx) > 0) {
          # Get the ARRAYADDRESS for the first five probes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }

	##Can do the mapping from array address to illumina ID using a revmap
	
	y<- revmap(illuminaMousev1ARRAYADDRESS)
	
        mapped_probes <- mappedkeys(y)
        # Convert to a list
        yy <- as.list(y[mapped_probes])
        if(length(yy) > 0) {
          # Get the ARRAYADDRESS for the first five probes
          yy[1:5]
          # Get the first one
          yy[[1]]
        }
	


        x <- illuminaMousev1CODINGZONE

        mapped_probes <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_probes])
        if(length(xx) > 0) {
          # Get the CODINGZONE for the first five probes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }

        x <- illuminaMousev1PROBESEQUENCE

        mapped_probes <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_probes])
        if(length(xx) > 0) {
          # Get the PROBESEQUENCE for the first five probes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }


}
\keyword{datasets}

==> illuminaMousev1.db_1.14.0.tar.gz: illuminaMousev1.db/man/illuminaMousev1NewMappings.Rd <==
\name{illuminaMousev1listNewMappings}
\alias{illuminaMousev1ARRAYADDRESS}
\alias{illuminaMousev1NUID}
\alias{illuminaMousev1PROBESEQUENCE}
\alias{illuminaMousev1PROBEQUALITY}
\alias{illuminaMousev1CODINGZONE}
\alias{illuminaMousev1GENOMICLOCATION}
\alias{illuminaMousev1GENOMICMATCHSIMILARITY}
\alias{illuminaMousev1SECONDMATCHES}
\alias{illuminaMousev1SECONDMATCHSIMILARITY}
\alias{illuminaMousev1TRANSCRIPTOMICMATCHSIMILARITY}
\alias{illuminaMousev1OTHERGENOMICMATCHES}
\alias{illuminaMousev1REPEATMASK}
\alias{illuminaMousev1OVERLAPPINGSNP}
\alias{illuminaMousev1ENTREZREANNOTATED}
\alias{illuminaMousev1ENSEMBLREANNOTATED}
\alias{illuminaMousev1SYMBOLREANNOTATED}
\alias{illuminaMousev1listNewMappings}
\alias{illuminaMousev1fullReannotation}
\alias{illuminaMousev1REPORTERGROUPNAME}
\alias{illuminaMousev1REPORTERGROUPID}

\title{Custom mappings added to the package}
\description{
We have used an extensive re-annotation of the illuminaMousev1 probe sequences to provide additional information that is not captured in the standard Bioconductor packages. Whereas Bioconductor annotations are based on the RefSeq ID that each probe maps to, our additional mappings provide data specific to each probe on the platform. See below for details. We recommend using the probe quality as a form of filtering, and retaining only perfect or good probes for an analysis. 

}

\section{Details of custom mappings}{

\describe{

\item{illuminaMousev1listNewMappings}{List all the custom re-annotation mappings provided by the package}

\item{illuminaMousev1fullReannotation}{Return all the re-annotation information as a matrix}

\item{illuminaMousev1ARRAYADDRESS}{Array Address code used to identify the probe at the bead-level}

\item{illuminaMousev1NUID}{Lumi's nuID (universal naming scheme for oligonucleotides) Reference: Du et al. (2007), Biol Direct 2:16}

\item{illuminaMousev1PROBESEQUENCE}{The 50 base sequence for the probe}

\item{illuminaMousev1PROBEQUALITY}{Quality grade assigned to the probe: \dQuote{Perfect} if it perfectly and uniquely matches the target transcript; \dQuote{Good} if the probe, although imperfectly matching the target transcript, is still likely to provide considerably sensitive signal (up to two mismatches are allowed, based on empirical evidence that the signal intensity for 50-mer probes with less than 95\% identity to the respective targets is less than 50\% of the signal associated with perfect matches *); \dQuote{Bad} if the probe matches repeat sequences, intergenic or intronic regions, or is unlikely to provide specific signal for any transcript; \dQuote{No match} if it does not match any genomic region or transcript.}

\item{illuminaMousev1CODINGZONE}{Coding status of target sequence: intergenic / intronic / Transcriptomic (\dQuote{Transcriptomic} when the target transcript is non-coding or there is no information on the coding sequence)}

\item{illuminaMousev1GENOMICLOCATION}{Probe's genomic coordinates (hg19 for human, mm9 for mouse or rn4 for rat)}

\item{illuminaMousev1GENOMICMATCHSIMILARITY}{Percentage of similarity between the probe and its best genomic match in the alignable region, taking the probe as reference}

\item{illuminaMousev1SECONDMATCHES}{Genomic coordinates of second best matches between the probe and the genome}

\item{illuminaMousev1SECONDMATCHSIMILARITY}{Percentage of similarity between the probe and its second best genomic match in the alignable region, taking the probe as reference}

\item{illuminaMousev1TRANSCRIPTOMICMATCHSIMILARITY}{Percentage of similarity between the probe and its target transcript in the alignable region, taking the probe as reference}

\item{illuminaMousev1OTHERGENOMICMATCHES}{Genomic coordinates of sequences as alignable with the probe (in terms of number of matching nucleotides) as its main target}

\item{illuminaMousev1REPEATMASK}{Overlapping RepeatMasked sequences, with number of bases overlapped by the repeat}

\item{illuminaMousev1OVERLAPPINGSNP}{Overlapping annotated SNPs}

\item{illuminaMousev1ENTREZREANNOTATED}{Entrez IDs}

\item{illuminaMousev1ENSEMBLREANNOTATED}{Ensembl IDs}

\item{illuminaMousev1SYMBOLREANNOTATED}{Gene symbol derived by re-annotation}

\item{illuminaMousev1REPORTERGROUPID}{For probes marked as controls in Illuminas annotation file, these gives the type of control}

\item{illuminaMousev1REPORTERGROUPNAME}{Usually a more informative name for the control type}



}

}

\references{
  \url{http://remoat.sysbiol.cam.ac.uk}


 Barbosa-Morais et al. (2010) A re-annotation pipeline for Illumina BeadArrays: improving the interpretation of gene expression data. Nucleic Acids Research

}
\examples{

	##See what new mappings are available

	illuminaMousev1listNewMappings()
	

        x <- illuminaMousev1PROBEQUALITY

        mapped_probes <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_probes])
        if(length(xx) > 0) {
          # Get the PROBEQUALITY for the first five probes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }


	##Overall table of qualities
	table(unlist(xx))

	

        x <- illuminaMousev1ARRAYADDRESS

        mapped_probes <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_probes])
        if(length(xx) > 0) {
          # Get the ARRAYADDRESS for the first five probes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }

	##Can do the mapping from array address to illumina ID using a revmap
	
	y<- revmap(illuminaMousev1ARRAYADDRESS)
	
        mapped_probes <- mappedkeys(y)
        # Convert to a list
        yy <- as.list(y[mapped_probes])
        if(length(yy) > 0) {
          # Get the ARRAYADDRESS for the first five probes
          yy[1:5]
          # Get the first one
          yy[[1]]
        }
	


        x <- illuminaMousev1CODINGZONE

        mapped_probes <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_probes])
        if(length(xx) > 0) {
          # Get the CODINGZONE for the first five probes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }

        x <- illuminaMousev1PROBESEQUENCE

        mapped_probes <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_probes])
        if(length(xx) > 0) {
          # Get the PROBESEQUENCE for the first five probes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }


}
\keyword{datasets}
